==> jc-1.4.0.tar.gz: java/io/ObjectStreamClass__24MemberComparator.h <==
// final class java.io.ObjectStreamClass$MemberComparator

// class file dependencies
// @dep_class f3898fc2584a61c java_io_ObjectStreamClass__24MemberComparator
// @dep_class 2a7152deee1944f1 java_lang_Object

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_java_io_ObjectStreamClass__24MemberComparator_H_
#define _JC_java_io_ObjectStreamClass__24MemberComparator_H_

// Forward structure declarations
struct _jc_java_io_ObjectStreamClass__241$object;
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;

// Typedefs
typedef struct _jc_java_io_ObjectStreamClass__24MemberComparator$sub_refs	_jc_java_io_ObjectStreamClass__24MemberComparator$sub_refs;
typedef struct _jc_java_io_ObjectStreamClass__24MemberComparator$sub_nonrefs	_jc_java_io_ObjectStreamClass__24MemberComparator$sub_nonrefs;
typedef struct _jc_java_io_ObjectStreamClass__24MemberComparator$refs	_jc_java_io_ObjectStreamClass__24MemberComparator$refs;
typedef struct _jc_java_io_ObjectStreamClass__24MemberComparator$nonrefs	_jc_java_io_ObjectStreamClass__24MemberComparator$nonrefs;
typedef struct _jc_java_io_ObjectStreamClass__24MemberComparator$object	_jc_java_io_ObjectStreamClass__24MemberComparator$object;

typedef const struct _jc_java_io_ObjectStreamClass__24MemberComparator$vmethods	_jc_java_io_ObjectStreamClass__24MemberComparator$vmethods;
typedef const struct _jc_java_io_ObjectStreamClass__24MemberComparator$vtable	_jc_java_io_ObjectStreamClass__24MemberComparator$vtable;
typedef const struct _jc_java_io_ObjectStreamClass__24MemberComparator$vtype	_jc_java_io_ObjectStreamClass__24MemberComparator$vtype;

// Constructors
extern void _jc_java_io_ObjectStreamClass__24MemberComparator$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_java_io_ObjectStreamClass__24MemberComparator$object *);
extern void _jc_java_io_ObjectStreamClass__24MemberComparator$method$_init$9e3450254cd18dd9(_jc_env *, struct _jc_java_io_ObjectStreamClass__24MemberComparator$object *, struct _jc_java_io_ObjectStreamClass__241$object *);

// Virtual methods
extern jint _jc_java_io_ObjectStreamClass__24MemberComparator$method$compare$ef65339aa5f9531b(_jc_env *, struct _jc_java_io_ObjectStreamClass__24MemberComparator$object *, struct _jc_java_lang_Object$object *, struct _jc_java_lang_Object$object *);

// Virtual method descriptors
extern _jc_method _jc_java_io_ObjectStreamClass__24MemberComparator$method_info$compare$ef65339aa5f9531b;

// Virtual methods structure
struct _jc_java_io_ObjectStreamClass__24MemberComparator$vmethods {
	jint	(*compare$ef65339aa5f9531b)(_jc_env *, struct _jc_java_io_ObjectStreamClass__24MemberComparator$object *, struct _jc_java_lang_Object$object *, struct _jc_java_lang_Object$object *);
};

// Vtable
struct _jc_java_io_ObjectStreamClass__24MemberComparator$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_io_ObjectStreamClass__24MemberComparator$vmethods	java_io_ObjectStreamClass__24MemberComparator;
};

// Vtype
struct _jc_java_io_ObjectStreamClass__24MemberComparator$vtype {
	_jc_type			type;
	_jc_java_io_ObjectStreamClass__24MemberComparator$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_io_ObjectStreamClass__24MemberComparator$sub_refs {
};

// Reference instance fields (object)
struct _jc_java_io_ObjectStreamClass__24MemberComparator$refs {
    _jc_java_io_ObjectStreamClass__24MemberComparator$sub_refs	java_io_ObjectStreamClass__24MemberComparator;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_io_ObjectStreamClass__24MemberComparator$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_java_io_ObjectStreamClass__24MemberComparator$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_io_ObjectStreamClass__24MemberComparator$sub_nonrefs	java_io_ObjectStreamClass__24MemberComparator;
};

// Object instance structure
struct _jc_java_io_ObjectStreamClass__24MemberComparator$object {
	_jc_java_io_ObjectStreamClass__24MemberComparator$refs	refs[0];
	_jc_word		lockword;
	_jc_java_io_ObjectStreamClass__24MemberComparator$vtype	*vtype;
	_jc_java_io_ObjectStreamClass__24MemberComparator$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_io_ObjectStreamClass__24MemberComparator$vtype _jc_java_io_ObjectStreamClass__24MemberComparator$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_io_ObjectStreamClass__24MemberComparator, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_io_ObjectStreamClass__24MemberComparator$class_object;

#endif	/* _JC_java_io_ObjectStreamClass__24MemberComparator_H_ */

==> jc-1.4.5.tar.gz: java/io/ObjectStreamClass__24MemberComparator.h <==
// final class java.io.ObjectStreamClass$MemberComparator

// class file dependencies
// @dep_class f3898fc2584a61c java_io_ObjectStreamClass__24MemberComparator
// @dep_class 1c4f1fc002fc96e5 java_lang_Object

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_java_io_ObjectStreamClass__24MemberComparator_H_
#define _JC_java_io_ObjectStreamClass__24MemberComparator_H_

// Forward structure declarations
struct _jc_java_io_ObjectStreamClass__241$object;
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;

// Typedefs
typedef struct _jc_java_io_ObjectStreamClass__24MemberComparator$sub_refs	_jc_java_io_ObjectStreamClass__24MemberComparator$sub_refs;
typedef struct _jc_java_io_ObjectStreamClass__24MemberComparator$sub_nonrefs	_jc_java_io_ObjectStreamClass__24MemberComparator$sub_nonrefs;
typedef struct _jc_java_io_ObjectStreamClass__24MemberComparator$refs	_jc_java_io_ObjectStreamClass__24MemberComparator$refs;
typedef struct _jc_java_io_ObjectStreamClass__24MemberComparator$nonrefs	_jc_java_io_ObjectStreamClass__24MemberComparator$nonrefs;
typedef struct _jc_java_io_ObjectStreamClass__24MemberComparator$object	_jc_java_io_ObjectStreamClass__24MemberComparator$object;

typedef const struct _jc_java_io_ObjectStreamClass__24MemberComparator$vmethods	_jc_java_io_ObjectStreamClass__24MemberComparator$vmethods;
typedef const struct _jc_java_io_ObjectStreamClass__24MemberComparator$vtable	_jc_java_io_ObjectStreamClass__24MemberComparator$vtable;
typedef const struct _jc_java_io_ObjectStreamClass__24MemberComparator$vtype	_jc_java_io_ObjectStreamClass__24MemberComparator$vtype;

// Constructors
extern void _jc_java_io_ObjectStreamClass__24MemberComparator$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_java_io_ObjectStreamClass__24MemberComparator$object *) _JC_JCNI_ATTR;
extern void _jc_java_io_ObjectStreamClass__24MemberComparator$method$_init$9e3450254cd18dd9(_jc_env *, struct _jc_java_io_ObjectStreamClass__24MemberComparator$object *, struct _jc_java_io_ObjectStreamClass__241$object *) _JC_JCNI_ATTR;

// Virtual methods
extern jint _jc_java_io_ObjectStreamClass__24MemberComparator$method$compare$ef65339aa5f9531b(_jc_env *, struct _jc_java_io_ObjectStreamClass__24MemberComparator$object *, struct _jc_java_lang_Object$object *, struct _jc_java_lang_Object$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_java_io_ObjectStreamClass__24MemberComparator$method_info$compare$ef65339aa5f9531b;

// Virtual methods structure
struct _jc_java_io_ObjectStreamClass__24MemberComparator$vmethods {
	jint	(*compare$ef65339aa5f9531b)(_jc_env *, struct _jc_java_io_ObjectStreamClass__24MemberComparator$object *, struct _jc_java_lang_Object$object *, struct _jc_java_lang_Object$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_java_io_ObjectStreamClass__24MemberComparator$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_io_ObjectStreamClass__24MemberComparator$vmethods	java_io_ObjectStreamClass__24MemberComparator;
};

// Vtype
struct _jc_java_io_ObjectStreamClass__24MemberComparator$vtype {
	_jc_type			type;
	_jc_java_io_ObjectStreamClass__24MemberComparator$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_io_ObjectStreamClass__24MemberComparator$sub_refs {
};

// Reference instance fields (object)
struct _jc_java_io_ObjectStreamClass__24MemberComparator$refs {
    _jc_java_io_ObjectStreamClass__24MemberComparator$sub_refs	java_io_ObjectStreamClass__24MemberComparator;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_io_ObjectStreamClass__24MemberComparator$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_java_io_ObjectStreamClass__24MemberComparator$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_io_ObjectStreamClass__24MemberComparator$sub_nonrefs	java_io_ObjectStreamClass__24MemberComparator;
};

// Object instance structure
struct _jc_java_io_ObjectStreamClass__24MemberComparator$object {
	_jc_java_io_ObjectStreamClass__24MemberComparator$refs	refs[0];
	_jc_word		lockword;
	_jc_java_io_ObjectStreamClass__24MemberComparator$vtype	*vtype;
	_jc_java_io_ObjectStreamClass__24MemberComparator$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_io_ObjectStreamClass__24MemberComparator$vtype _jc_java_io_ObjectStreamClass__24MemberComparator$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_io_ObjectStreamClass__24MemberComparator, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_io_ObjectStreamClass__24MemberComparator$class_object;

#endif	/* _JC_java_io_ObjectStreamClass__24MemberComparator_H_ */
